apply

package
v0.2.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 11, 2025 License: Apache-2.0 Imports: 10 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var ApplyCmd = &cobra.Command{
	Use:   "apply",
	Short: "Create or update a resource from a file or from stdin",
	Long: `Create or update a resource from a file or from stdin.

Available subcommands:
  repo   Create a repository	
  repos   Bulk create repositories
`,
}

Functions

This section is empty.

Types

type RepoWebhookYAML added in v0.2.0

type RepoWebhookYAML struct {
	Project         string   `yaml:"project"`
	RepoSlug        string   `yaml:"slug"`
	Name            string   `yaml:"name"`
	URL             string   `yaml:"url"`
	Events          []string `yaml:"events"`
	Active          *bool    `yaml:"active,omitempty"`
	Username        string   `yaml:"username,omitempty"`
	Password        string   `yaml:"password,omitempty"`
	SSLVerification *bool    `yaml:"sslVerificationRequired,omitempty"`
}

type RepoWebhooksFile added in v0.2.0

type RepoWebhooksFile struct {
	Webhooks []RepoWebhookYAML `yaml:"webhooks"`
}

type RepoYAML added in v0.2.0

type RepoYAML struct {
	Name        string `yaml:"name"`
	Slug        string `yaml:"slug"`
	Branch      string `yaml:"branch"`
	Project     string `yaml:"project"`
	Description string `yaml:"description"`
}

type ReposFile added in v0.2.0

type ReposFile struct {
	Repos []RepoYAML `yaml:"repos"`
}

Jump to