Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var CreateCmd = &cobra.Command{
Use: "create",
Short: "Create a resource from a file or from stdin",
Long: `Create a resource from a file or from stdin.
Available subcommands:
repo Create a repository
repos Bulk create repositories
`,
}
Functions ¶
This section is empty.
Types ¶
type RepoWebhookYAML ¶ added in v0.2.0
type RepoWebhookYAML struct {
Project string `yaml:"project"`
RepoSlug string `yaml:"slug"`
Name string `yaml:"name"`
URL string `yaml:"url"`
Events []string `yaml:"events"`
Active *bool `yaml:"active,omitempty"`
Username string `yaml:"username,omitempty"`
Password string `yaml:"password,omitempty"`
SSLVerification *bool `yaml:"sslVerificationRequired,omitempty"`
}
type RepoWebhooksFile ¶ added in v0.2.0
type RepoWebhooksFile struct {
Webhooks []RepoWebhookYAML `yaml:"webhooks"`
}
Click to show internal directories.
Click to hide internal directories.