delete

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 11, 2025 License: Apache-2.0 Imports: 8 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var DeleteCmd = &cobra.Command{
	Use:   "delete",
	Short: "Delete a resource from a file or from stdin",
	Long: `Delete a resource from a file or from stdin.

Available subcommands:
  repo   Delete a repository	
  repos   Bulk delete repositories
`,
}

Functions

This section is empty.

Types

type RepoWebhookYAML added in v0.2.0

type RepoWebhookYAML struct {
	Project  string `yaml:"project"`
	RepoSlug string `yaml:"repoSlug"`
	Name     string `yaml:"name"`
}

type RepoWebhooksFile added in v0.2.0

type RepoWebhooksFile struct {
	Webhooks []RepoWebhookYAML `yaml:"webhooks"`
}

type RepoYAML added in v0.2.0

type RepoYAML struct {
	Name    string `yaml:"name"`
	Slug    string `yaml:"slug"`
	Project string `yaml:"project"`
}

type ReposFile added in v0.2.0

type ReposFile struct {
	Repos []RepoYAML `yaml:"repos"`
}

Jump to