Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var DeleteCmd = &cobra.Command{
Use: "delete",
Short: "Delete a resource from a file or from stdin",
Long: `Delete a resource from a file or from stdin.
Available subcommands:
repo Delete a repository
repos Bulk delete repositories
`,
}
Functions ¶
This section is empty.
Types ¶
type RepoWebhookYAML ¶ added in v0.2.0
type RepoWebhooksFile ¶ added in v0.2.0
type RepoWebhooksFile struct {
Webhooks []RepoWebhookYAML `yaml:"webhooks"`
}
Click to show internal directories.
Click to hide internal directories.